==> kv5500-0.3.tar.gz: kv5500-0.3/src/gkv5500_file.cpp <==
/*****************************************************************************
 *
 *  gkv5500 - gtk2 frontend of kv5500 utility.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include "gkv5500_file.hpp"

using namespace KV5500;

GGetFileScanner::GGetFileScanner(unsigned int num, const std::string& filename, GtkWidget* label, GtkWidget* progressBar)
    : GetFileScanner(num),
      filename_(filename),
      label_(label),
      progressBar_(progressBar)
{
    assert(label && progressBar);

    gtk_widget_set_sensitive(progressBar_, TRUE);
}

GGetFileScanner::~GGetFileScanner()
{}

void GGetFileScanner::PrintError(const std::string& msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg.c_str());

    gtk_widget_set_sensitive(progressBar_, FALSE);

    gdk_flush();
    gdk_threads_leave();
}

void GGetFileScanner::Print(const std::string& msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg.c_str());

    gdk_flush();
    gdk_threads_leave();
}

void GGetFileScanner::PrintProcess(unsigned int complete, unsigned int total)
{
    gdk_threads_enter();

    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar_), static_cast<double>(complete) / total);

    gdk_flush();
    gdk_threads_leave();
}

void GGetFileScanner::PrintEnd(const std::string& msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg.c_str());
    gtk_widget_set_sensitive(progressBar_, FALSE);

    gdk_flush();
    gdk_threads_leave();
}

std::string GGetFileScanner::GetFilename() const
{
    return filename_;
}

==> kv5500-0.3.1.tar.gz: kv5500-0.3.1/src/gkv5500_file.cpp <==
/*****************************************************************************
 *
 *  gkv5500 - gtk2 frontend of kv5500 utility.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include "gkv5500_file.hpp"

using namespace KV5500;

void GtkDisplay::PrintError(const char* msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg);

    gtk_widget_set_sensitive(progressBar_, FALSE);

    gdk_flush();
    gdk_threads_leave();
}

void GtkDisplay::Print(const std::string& msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg.c_str());

    gdk_flush();
    gdk_threads_leave();
}

void GtkDisplay::PrintProcess(unsigned int complete, unsigned int total)
{
    gdk_threads_enter();

    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar_), static_cast<double>(complete) / total);

    gdk_flush();
    gdk_threads_leave();
}

void GtkDisplay::PrintEnd(const std::string& msg)
{
    gdk_threads_enter();

    gtk_label_set_text(GTK_LABEL(label_), msg.c_str());
    gtk_widget_set_sensitive(progressBar_, FALSE);

    gdk_flush();
    gdk_threads_leave();
}
